@@ -23,6 +23,7 @@ use Aws\S3\Iterator\ListObjectsIterator;
 use Guzzle\Http\EntityBody;
 use Guzzle\Http\CachingEntityBody;
 use Guzzle\Http\Mimetypes;
+use Guzzle\Iterator\FilterIterator;
 use Guzzle\Stream\PhpStreamRequestFactory;
 use Guzzle\Service\Command\CommandInterface;
 
@@ -132,7 +133,7 @@ class StreamWrapper
             stream_wrapper_unregister('s3');
         }
 
-        stream_wrapper_register('s3', __CLASS__, STREAM_IS_URL);
+        stream_wrapper_register('s3', get_called_class(), STREAM_IS_URL);
         self::$client = $client;
     }
 
@@ -365,7 +366,7 @@ class StreamWrapper
      * @param string $path    Directory which should be created.
      * @param int    $mode    Permissions. 700-range permissions map to ACL_PUBLIC. 600-range permissions map to
      *                        ACL_AUTH_READ. All other permissions map to ACL_PRIVATE. Expects octal form.
-     * @param int    $options A bitwise mask of values, such as STREAM_MKDIR_RECURSIVE. (unused)
+     * @param int    $options A bitwise mask of values, such as STREAM_MKDIR_RECURSIVE.
      *
      * @return bool
      * @link http://www.php.net/manual/en/streamwrapper.mkdir.php
@@ -373,28 +374,17 @@ class StreamWrapper
     public function mkdir($path, $mode, $options)
     {
         $params = $this->getParams($path);
-        $this->clearStatInfo($path);
-
-        if (!$params['Bucket'] || $params['Key']) {
+        if (!$params['Bucket']) {
             return false;
         }
 
-        try {
-            if (!isset($params['ACL'])) {
-                $mode = decoct($mode);
-                if ($mode >= 700 and $mode <= 799) {
-                    $params['ACL'] = 'public-read';
-                } elseif ($mode >= 600 && $mode <= 699) {
-                    $params['ACL'] = 'authenticated-read';
-                } else {
-                    $params['ACL'] = 'private';
-                }
-            }
-            self::$client->createBucket($params);
-            return true;
-        } catch (\Exception $e) {
-            return $this->triggerError($e->getMessage());
+        if (!isset($params['ACL'])) {
+            $params['ACL'] = $this->determineAcl($mode);
         }
+
+        return !isset($params['Key']) || $params['Key'] === '/'
+            ? $this->createBucket($path, $params)
+            : $this->createPseudoDirectory($path, $params);
     }
 
     /**
@@ -455,11 +445,20 @@ class StreamWrapper
             $operationParams['Delimiter'] = $delimiter;
         }
 
-        $this->objectIterator = self::$client->getIterator('ListObjects', $operationParams, array(
+        $objectIterator = self::$client->getIterator('ListObjects', $operationParams, array(
             'return_prefixes' => true,
             'sort_results'    => true
         ));
 
+        // Filter our "/" keys added by the console as directories
+        $this->objectIterator = new FilterIterator(
+            $objectIterator,
+            function ($key) {
+                // Each yielded results can contain a "Key" or "Prefix"
+                return !isset($key['Key']) || substr($key['Key'], -1, 1) !== '/';
+            }
+        );
+
         $this->objectIterator->next();
 
         return true;
@@ -499,27 +498,32 @@ class StreamWrapper
      */
     public function dir_readdir()
     {
-        $result = false;
-        if ($this->objectIterator->valid()) {
-            $current = $this->objectIterator->current();
-            if (isset($current['Prefix'])) {
-                // Include "directories". Be sure to strip a trailing "/" on prefixes.
-                $prefix = rtrim($current['Prefix'], '/');
-                $result = str_replace($this->openedBucketPrefix, '', $prefix);
-                $key = "s3://{$this->openedBucket}/{$prefix}";
-                $stat = $this->formatUrlStat($prefix);
-            } else {
-                // Remove the prefix from the result to emulate other stream wrappers
-                $result = str_replace($this->openedBucketPrefix, '', $current['Key']);
-                $key = "s3://{$this->openedBucket}/{$current['Key']}";
-                $stat = $this->formatUrlStat($current);
-            }
-
-            // Cache the object data for quick url_stat lookups used with RecursiveDirectoryIterator
-            self::$nextStat = array($key => $stat);
-            $this->objectIterator->next();
+        // Skip empty result keys
+        if (!$this->objectIterator->valid()) {
+            return false;
         }
 
+        $current = $this->objectIterator->current();
+        if (isset($current['Prefix'])) {
+            // Include "directories". Be sure to strip a trailing "/"
+            // on prefixes.
+            $prefix = rtrim($current['Prefix'], '/');
+            $result = str_replace($this->openedBucketPrefix, '', $prefix);
+            $key = "s3://{$this->openedBucket}/{$prefix}";
+            $stat = $this->formatUrlStat($prefix);
+        } else {
+            // Remove the prefix from the result to emulate other
+            // stream wrappers.
+            $result = str_replace($this->openedBucketPrefix, '', $current['Key']);
+            $key = "s3://{$this->openedBucket}/{$current['Key']}";
+            $stat = $this->formatUrlStat($current);
+        }
+
+        // Cache the object data for quick url_stat lookups used with
+        // RecursiveDirectoryIterator.
+        self::$nextStat = array($key => $stat);
+        $this->objectIterator->next();
+
         return $result;
     }
 
@@ -745,12 +749,13 @@ class StreamWrapper
         );
 
         $stat = $statTemplate;
+        $type = gettype($result);
 
         // Determine what type of data is being cached
-        if (!$result || is_string($result)) {
+        if (!$result || $type == 'string') {
             // Directory with 0777 access - see "man 2 stat".
             $stat['mode'] = $stat[2] = 0040777;
-        } elseif (is_array($result) && isset($result['LastModified'])) {
+        } elseif ($type == 'array' && isset($result['LastModified'])) {
             // ListObjects or HeadObject result
             $stat['mtime'] = $stat[9] = $stat['ctime'] = $stat[10] = strtotime($result['LastModified']);
             $stat['size'] = $stat[7] = (isset($result['ContentLength']) ? $result['ContentLength'] : $result['Size']);
@@ -775,4 +780,77 @@ class StreamWrapper
             clearstatcache(true, $path);
         }
     }
+
+    /**
+     * Creates a bucket for the given parameters.
+     *
+     * @param string $path   Stream wrapper path
+     * @param array  $params A result of StreamWrapper::getParams()
+     *
+     * @return bool Returns true on success or false on failure
+     */
+    private function createBucket($path, array $params)
+    {
+        if (self::$client->doesBucketExist($params['Bucket'])) {
+            return $this->triggerError("Directory already exists: {$path}");
+        }
+
+        try {
+            self::$client->createBucket($params);
+            $this->clearStatInfo($path);
+            return true;
+        } catch (\Exception $e) {
+            return $this->triggerError($e->getMessage());
+        }
+    }
+
+    /**
+     * Creates a pseudo-folder by creating an empty "/" suffixed key
+     *
+     * @param string $path   Stream wrapper path
+     * @param array  $params A result of StreamWrapper::getParams()
+     *
+     * @return bool
+     */
+    private function createPseudoDirectory($path, array $params)
+    {
+        // Ensure the path ends in "/" and the body is empty.
+        $params['Key'] = rtrim($params['Key'], '/') . '/';
+        $params['Body'] = '';
+
+        // Fail if this pseudo directory key already exists
+        if (self::$client->doesObjectExist($params['Bucket'], $params['Key'])) {
+            return $this->triggerError("Directory already exists: {$path}");
+        }
+
+        try {
+            self::$client->putObject($params);
+            $this->clearStatInfo($path);
+            return true;
+        } catch (\Exception $e) {
+            return $this->triggerError($e->getMessage());
+        }
+    }
+
+    /**
+     * Determine the most appropriate ACL based on a file mode.
+     *
+     * @param int $mode File mode
+     *
+     * @return string
+     */
+    private function determineAcl($mode)
+    {
+        $mode = decoct($mode);
+
+        if ($mode >= 700 && $mode <= 799) {
+            return 'public-read';
+        }
+
+        if ($mode >= 600 && $mode <= 699) {
+            return 'authenticated-read';
+        }
+
+        return 'private';
+    }
 }
